# TP Helper

Collection of common practices used in Transpropusk's projects.

## Установка:
`poetry add tp-helper`

## Публикация:
Собирает и загружает собранный пакет в PyPI.

`poetry publish --build`